import { APIMeta, AcceptInviteRequest, CreateAPITokenRequest, CreateAPITokenResponse, CreatePullRequestFromStepRun, CreateTenantInviteRequest, CreateTenantRequest, EventData, EventKey, EventKeyList, EventList, EventOrderByDirection, EventOrderByField, EventSearch, GetStepRunDiffResponse, LinkGithubRepositoryRequest, ListAPIMetaIntegration, ListAPITokensResponse, ListGithubAppInstallationsResponse, ListGithubBranchesResponse, ListGithubReposResponse, ListPullRequestsResponse, PullRequestState, RejectInviteRequest, ReplayEventRequest, RerunStepRunRequest, StepRun, Tenant, TenantInvite, TenantInviteList, TenantMemberList, TriggerWorkflowRunRequest, UpdateTenantInviteRequest, User, UserLoginRequest, UserRegisterRequest, UserTenantMembershipsList, Worker, WorkerList, Workflow, WorkflowID, WorkflowList, WorkflowRun, WorkflowRunList, WorkflowVersion, WorkflowVersionDefinition } from './data-contracts';
import { HttpClient, RequestParams } from './http-client';
export declare class Api<SecurityDataType = unknown> extends HttpClient<SecurityDataType> {
    /**
     * @description Gets metadata for the Hatchet instance
     *
     * @tags Metadata
     * @name MetadataGet
     * @summary Get metadata
     * @request GET:/api/v1/meta
     */
    metadataGet: (params?: RequestParams) => Promise<import("axios").AxiosResponse<APIMeta, any>>;
    /**
     * @description List all integrations
     *
     * @tags Metadata
     * @name MetadataListIntegrations
     * @summary List integrations
     * @request GET:/api/v1/meta/integrations
     * @secure
     */
    metadataListIntegrations: (params?: RequestParams) => Promise<import("axios").AxiosResponse<ListAPIMetaIntegration, any>>;
    /**
     * @description Logs in a user.
     *
     * @tags User
     * @name UserUpdateLogin
     * @summary Login user
     * @request POST:/api/v1/users/login
     */
    userUpdateLogin: (data: UserLoginRequest, params?: RequestParams) => Promise<import("axios").AxiosResponse<User, any>>;
    /**
     * @description Starts the OAuth flow
     *
     * @tags User
     * @name UserUpdateGoogleOauthStart
     * @summary Start OAuth flow
     * @request GET:/api/v1/users/google/start
     */
    userUpdateGoogleOauthStart: (params?: RequestParams) => Promise<import("axios").AxiosResponse<any, any>>;
    /**
     * @description Completes the OAuth flow
     *
     * @tags User
     * @name UserUpdateGoogleOauthCallback
     * @summary Complete OAuth flow
     * @request GET:/api/v1/users/google/callback
     */
    userUpdateGoogleOauthCallback: (params?: RequestParams) => Promise<import("axios").AxiosResponse<any, any>>;
    /**
     * @description Starts the OAuth flow
     *
     * @tags User
     * @name UserUpdateGithubOauthStart
     * @summary Start OAuth flow
     * @request GET:/api/v1/users/github/start
     * @secure
     */
    userUpdateGithubOauthStart: (params?: RequestParams) => Promise<import("axios").AxiosResponse<any, any>>;
    /**
     * @description Completes the OAuth flow
     *
     * @tags User
     * @name UserUpdateGithubOauthCallback
     * @summary Complete OAuth flow
     * @request GET:/api/v1/users/github/callback
     * @secure
     */
    userUpdateGithubOauthCallback: (params?: RequestParams) => Promise<import("axios").AxiosResponse<any, any>>;
    /**
     * @description Github App global webhook
     *
     * @tags Github
     * @name GithubUpdateGlobalWebhook
     * @summary Github app global webhook
     * @request POST:/api/v1/github/webhook
     */
    githubUpdateGlobalWebhook: (params?: RequestParams) => Promise<import("axios").AxiosResponse<void, any>>;
    /**
     * @description Github App tenant webhook
     *
     * @tags Github
     * @name GithubUpdateTenantWebhook
     * @summary Github app tenant webhook
     * @request POST:/api/v1/github/webhook/{webhook}
     */
    githubUpdateTenantWebhook: (webhook: string, params?: RequestParams) => Promise<import("axios").AxiosResponse<void, any>>;
    /**
     * @description Gets the current user
     *
     * @tags User
     * @name UserGetCurrent
     * @summary Get current user
     * @request GET:/api/v1/users/current
     * @secure
     */
    userGetCurrent: (params?: RequestParams) => Promise<import("axios").AxiosResponse<User, any>>;
    /**
     * @description Registers a user.
     *
     * @tags User
     * @name UserCreate
     * @summary Register user
     * @request POST:/api/v1/users/register
     */
    userCreate: (data: UserRegisterRequest, params?: RequestParams) => Promise<import("axios").AxiosResponse<User, any>>;
    /**
     * @description Logs out a user.
     *
     * @tags User
     * @name UserUpdateLogout
     * @summary Logout user
     * @request POST:/api/v1/users/logout
     * @secure
     */
    userUpdateLogout: (params?: RequestParams) => Promise<import("axios").AxiosResponse<User, any>>;
    /**
     * @description Lists all tenant memberships for the current user
     *
     * @tags User
     * @name TenantMembershipsList
     * @summary List tenant memberships
     * @request GET:/api/v1/users/memberships
     * @secure
     */
    tenantMembershipsList: (params?: RequestParams) => Promise<import("axios").AxiosResponse<UserTenantMembershipsList, any>>;
    /**
     * @description Lists all tenant invites for the current user
     *
     * @tags Tenant
     * @name UserListTenantInvites
     * @summary List tenant invites
     * @request GET:/api/v1/users/invites
     * @secure
     */
    userListTenantInvites: (params?: RequestParams) => Promise<import("axios").AxiosResponse<TenantInviteList, any>>;
    /**
     * @description Accepts a tenant invite
     *
     * @tags Tenant
     * @name TenantInviteAccept
     * @summary Accept tenant invite
     * @request POST:/api/v1/users/invites/accept
     * @secure
     */
    tenantInviteAccept: (data: AcceptInviteRequest, params?: RequestParams) => Promise<import("axios").AxiosResponse<void, any>>;
    /**
     * @description Rejects a tenant invite
     *
     * @tags Tenant
     * @name TenantInviteReject
     * @summary Reject tenant invite
     * @request POST:/api/v1/users/invites/reject
     * @secure
     */
    tenantInviteReject: (data: RejectInviteRequest, params?: RequestParams) => Promise<import("axios").AxiosResponse<void, any>>;
    /**
     * @description Creates a new tenant
     *
     * @tags Tenant
     * @name TenantCreate
     * @summary Create tenant
     * @request POST:/api/v1/tenants
     * @secure
     */
    tenantCreate: (data: CreateTenantRequest, params?: RequestParams) => Promise<import("axios").AxiosResponse<Tenant, any>>;
    /**
     * @description Creates a new tenant invite
     *
     * @tags Tenant
     * @name TenantInviteCreate
     * @summary Create tenant invite
     * @request POST:/api/v1/tenants/{tenant}/invites
     * @secure
     */
    tenantInviteCreate: (tenant: string, data: CreateTenantInviteRequest, params?: RequestParams) => Promise<import("axios").AxiosResponse<TenantInvite, any>>;
    /**
     * @description Gets a list of tenant invites
     *
     * @tags Tenant
     * @name TenantInviteList
     * @summary List tenant invites
     * @request GET:/api/v1/tenants/{tenant}/invites
     * @secure
     */
    tenantInviteList: (tenant: string, params?: RequestParams) => Promise<import("axios").AxiosResponse<TenantInviteList, any>>;
    /**
     * @description Updates a tenant invite
     *
     * @name TenantInviteUpdate
     * @summary Update invite
     * @request PATCH:/api/v1/tenants/{tenant}/invites/{tenant-invite}
     * @secure
     */
    tenantInviteUpdate: (tenant: string, tenantInvite: string, data: UpdateTenantInviteRequest, params?: RequestParams) => Promise<import("axios").AxiosResponse<TenantInvite, any>>;
    /**
     * @description Deletes a tenant invite
     *
     * @name TenantInviteDelete
     * @summary Delete invite
     * @request DELETE:/api/v1/tenants/{tenant}/invites/{tenant-invite}
     * @secure
     */
    tenantInviteDelete: (tenant: string, tenantInvite: string, params?: RequestParams) => Promise<import("axios").AxiosResponse<TenantInvite, any>>;
    /**
     * @description Create an API token for a tenant
     *
     * @tags API Token
     * @name ApiTokenCreate
     * @summary Create API Token
     * @request POST:/api/v1/tenants/{tenant}/api-tokens
     * @secure
     */
    apiTokenCreate: (tenant: string, data: CreateAPITokenRequest, params?: RequestParams) => Promise<import("axios").AxiosResponse<CreateAPITokenResponse, any>>;
    /**
     * @description List API tokens for a tenant
     *
     * @tags API Token
     * @name ApiTokenList
     * @summary List API Tokens
     * @request GET:/api/v1/tenants/{tenant}/api-tokens
     * @secure
     */
    apiTokenList: (tenant: string, params?: RequestParams) => Promise<import("axios").AxiosResponse<ListAPITokensResponse, any>>;
    /**
     * @description Revoke an API token for a tenant
     *
     * @tags API Token
     * @name ApiTokenUpdateRevoke
     * @summary Revoke API Token
     * @request POST:/api/v1/api-tokens/{api-token}
     * @secure
     */
    apiTokenUpdateRevoke: (apiToken: string, params?: RequestParams) => Promise<import("axios").AxiosResponse<void, any>>;
    /**
     * @description Lists all events for a tenant.
     *
     * @tags Event
     * @name EventList
     * @summary List events
     * @request GET:/api/v1/tenants/{tenant}/events
     * @secure
     */
    eventList: (tenant: string, query?: {
        /**
         * The number to skip
         * @format int64
         */
        offset?: number;
        /**
         * The number to limit by
         * @format int64
         */
        limit?: number;
        /** A list of keys to filter by */
        keys?: EventKey[];
        /** A list of workflow IDs to filter by */
        workflows?: WorkflowID[];
        /** The search query to filter for */
        search?: EventSearch;
        /** What to order by */
        orderByField?: EventOrderByField;
        /** The order direction */
        orderByDirection?: EventOrderByDirection;
    }, params?: RequestParams) => Promise<import("axios").AxiosResponse<EventList, any>>;
    /**
     * @description Replays a list of events.
     *
     * @tags Event
     * @name EventUpdateReplay
     * @summary Replay events
     * @request POST:/api/v1/tenants/{tenant}/events/replay
     * @secure
     */
    eventUpdateReplay: (tenant: string, data: ReplayEventRequest, params?: RequestParams) => Promise<import("axios").AxiosResponse<EventList, any>>;
    /**
     * @description Gets a list of tenant members
     *
     * @tags Tenant
     * @name TenantMemberList
     * @summary List tenant members
     * @request GET:/api/v1/tenants/{tenant}/members
     * @secure
     */
    tenantMemberList: (tenant: string, params?: RequestParams) => Promise<import("axios").AxiosResponse<TenantMemberList, any>>;
    /**
     * @description Get the data for an event.
     *
     * @tags Event
     * @name EventDataGet
     * @summary Get event data
     * @request GET:/api/v1/events/{event}/data
     * @secure
     */
    eventDataGet: (event: string, params?: RequestParams) => Promise<import("axios").AxiosResponse<EventData, any>>;
    /**
     * @description Lists all event keys for a tenant.
     *
     * @tags Event
     * @name EventKeyList
     * @summary List event keys
     * @request GET:/api/v1/tenants/{tenant}/events/keys
     * @secure
     */
    eventKeyList: (tenant: string, params?: RequestParams) => Promise<import("axios").AxiosResponse<EventKeyList, any>>;
    /**
     * @description Get all workflows for a tenant
     *
     * @tags Workflow
     * @name WorkflowList
     * @summary Get workflows
     * @request GET:/api/v1/tenants/{tenant}/workflows
     * @secure
     */
    workflowList: (tenant: string, params?: RequestParams) => Promise<import("axios").AxiosResponse<WorkflowList, any>>;
    /**
     * @description Get a workflow for a tenant
     *
     * @tags Workflow
     * @name WorkflowGet
     * @summary Get workflow
     * @request GET:/api/v1/workflows/{workflow}
     * @secure
     */
    workflowGet: (workflow: string, params?: RequestParams) => Promise<import("axios").AxiosResponse<Workflow, any>>;
    /**
     * @description Get a workflow version for a tenant
     *
     * @tags Workflow
     * @name WorkflowVersionGet
     * @summary Get workflow version
     * @request GET:/api/v1/workflows/{workflow}/versions
     * @secure
     */
    workflowVersionGet: (workflow: string, query?: {
        /**
         * The workflow version. If not supplied, the latest version is fetched.
         * @format uuid
         * @minLength 36
         * @maxLength 36
         */
        version?: string;
    }, params?: RequestParams) => Promise<import("axios").AxiosResponse<WorkflowVersion, any>>;
    /**
     * @description Trigger a new workflow run for a tenant
     *
     * @tags Workflow Run
     * @name WorkflowRunCreate
     * @summary Trigger workflow run
     * @request POST:/api/v1/workflows/{workflow}/trigger
     * @secure
     */
    workflowRunCreate: (workflow: string, data: TriggerWorkflowRunRequest, query?: {
        /**
         * The workflow version. If not supplied, the latest version is fetched.
         * @format uuid
         * @minLength 36
         * @maxLength 36
         */
        version?: string;
    }, params?: RequestParams) => Promise<import("axios").AxiosResponse<WorkflowRun, any>>;
    /**
     * @description Get a workflow version definition for a tenant
     *
     * @tags Workflow
     * @name WorkflowVersionGetDefinition
     * @summary Get workflow version definition
     * @request GET:/api/v1/workflows/{workflow}/versions/definition
     * @secure
     */
    workflowVersionGetDefinition: (workflow: string, query?: {
        /**
         * The workflow version. If not supplied, the latest version is fetched.
         * @format uuid
         * @minLength 36
         * @maxLength 36
         */
        version?: string;
    }, params?: RequestParams) => Promise<import("axios").AxiosResponse<WorkflowVersionDefinition, any>>;
    /**
     * @description Link a github repository to a workflow
     *
     * @tags Workflow
     * @name WorkflowUpdateLinkGithub
     * @summary Link github repository
     * @request POST:/api/v1/workflows/{workflow}/link-github
     * @secure
     */
    workflowUpdateLinkGithub: (workflow: string, data: LinkGithubRepositoryRequest, params?: RequestParams) => Promise<import("axios").AxiosResponse<Workflow, any>>;
    /**
     * @description Create a pull request for a workflow
     *
     * @tags Workflow
     * @name StepRunUpdateCreatePr
     * @summary Create pull request
     * @request POST:/api/v1/step-runs/{step-run}/create-pr
     * @secure
     */
    stepRunUpdateCreatePr: (stepRun: string, data: CreatePullRequestFromStepRun, params?: RequestParams) => Promise<import("axios").AxiosResponse<CreatePullRequestFromStepRun, any>>;
    /**
     * @description Get the diff for a step run between the most recent run and the first run.
     *
     * @tags Workflow
     * @name StepRunGetDiff
     * @summary Get diff
     * @request GET:/api/v1/step-runs/{step-run}/diff
     * @secure
     */
    stepRunGetDiff: (stepRun: string, params?: RequestParams) => Promise<import("axios").AxiosResponse<GetStepRunDiffResponse, any>>;
    /**
     * @description Get all workflow runs for a tenant
     *
     * @tags Workflow
     * @name WorkflowRunList
     * @summary Get workflow runs
     * @request GET:/api/v1/tenants/{tenant}/workflows/runs
     * @secure
     */
    workflowRunList: (tenant: string, query?: {
        /**
         * The number to skip
         * @format int64
         */
        offset?: number;
        /**
         * The number to limit by
         * @format int64
         */
        limit?: number;
        /**
         * The event id to get runs for.
         * @format uuid
         * @minLength 36
         * @maxLength 36
         */
        eventId?: string;
        /**
         * The workflow id to get runs for.
         * @format uuid
         * @minLength 36
         * @maxLength 36
         */
        workflowId?: string;
    }, params?: RequestParams) => Promise<import("axios").AxiosResponse<WorkflowRunList, any>>;
    /**
     * @description Get a workflow run for a tenant
     *
     * @tags Workflow
     * @name WorkflowRunGet
     * @summary Get workflow run
     * @request GET:/api/v1/tenants/{tenant}/workflow-runs/{workflow-run}
     * @secure
     */
    workflowRunGet: (tenant: string, workflowRun: string, params?: RequestParams) => Promise<import("axios").AxiosResponse<WorkflowRun, any>>;
    /**
     * @description List all pull requests for a workflow run
     *
     * @tags Workflow
     * @name WorkflowRunListPullRequests
     * @summary List pull requests
     * @request GET:/api/v1/tenants/{tenant}/workflow-runs/{workflow-run}/prs
     * @secure
     */
    workflowRunListPullRequests: (tenant: string, workflowRun: string, query?: {
        /** The pull request state */
        state?: PullRequestState;
    }, params?: RequestParams) => Promise<import("axios").AxiosResponse<ListPullRequestsResponse, any>>;
    /**
     * @description Get a step run by id
     *
     * @tags Step Run
     * @name StepRunGet
     * @summary Get step run
     * @request GET:/api/v1/tenants/{tenant}/step-runs/{step-run}
     * @secure
     */
    stepRunGet: (tenant: string, stepRun: string, params?: RequestParams) => Promise<import("axios").AxiosResponse<StepRun, any>>;
    /**
     * @description Reruns a step run
     *
     * @tags Step Run
     * @name StepRunUpdateRerun
     * @summary Rerun step run
     * @request POST:/api/v1/tenants/{tenant}/step-runs/{step-run}/rerun
     * @secure
     */
    stepRunUpdateRerun: (tenant: string, stepRun: string, data: RerunStepRunRequest, params?: RequestParams) => Promise<import("axios").AxiosResponse<StepRun, any>>;
    /**
     * @description Get all workers for a tenant
     *
     * @tags Worker
     * @name WorkerList
     * @summary Get workers
     * @request GET:/api/v1/tenants/{tenant}/worker
     * @secure
     */
    workerList: (tenant: string, params?: RequestParams) => Promise<import("axios").AxiosResponse<WorkerList, any>>;
    /**
     * @description Get a worker
     *
     * @tags Worker
     * @name WorkerGet
     * @summary Get worker
     * @request GET:/api/v1/workers/{worker}
     * @secure
     */
    workerGet: (worker: string, params?: RequestParams) => Promise<import("axios").AxiosResponse<Worker, any>>;
    /**
     * @description List Github App installations
     *
     * @tags Github
     * @name GithubAppListInstallations
     * @summary List Github App installations
     * @request GET:/api/v1/github-app/installations
     * @secure
     */
    githubAppListInstallations: (params?: RequestParams) => Promise<import("axios").AxiosResponse<ListGithubAppInstallationsResponse, any>>;
    /**
     * @description List Github App repositories
     *
     * @tags Github
     * @name GithubAppListRepos
     * @summary List Github App repositories
     * @request GET:/api/v1/github-app/installations/{gh-installation}/repos
     * @secure
     */
    githubAppListRepos: (ghInstallation: string, params?: RequestParams) => Promise<import("axios").AxiosResponse<ListGithubReposResponse, any>>;
    /**
     * @description List Github App branches
     *
     * @tags Github
     * @name GithubAppListBranches
     * @summary List Github App branches
     * @request GET:/api/v1/github-app/installations/{gh-installation}/repos/{gh-repo-owner}/{gh-repo-name}/branches
     * @secure
     */
    githubAppListBranches: (ghInstallation: string, ghRepoOwner: string, ghRepoName: string, params?: RequestParams) => Promise<import("axios").AxiosResponse<ListGithubBranchesResponse, any>>;
}
