import { HatchetClient } from '../hatchet-client';
import { Action, ActionListener } from '../dispatcher/action-listener';
import { StepActionEvent, StepActionEventType, GroupKeyActionEvent, GroupKeyActionEventType } from '../../protoc/dispatcher';
import HatchetPromise from '../../util/hatchet-promise/hatchet-promise';
import { Workflow } from '../../workflow';
import { Logger } from '../../util/logger';
import { Context, StepRunFunction } from '../../step';
export type ActionRegistry = Record<Action['actionId'], Function>;
export declare class Worker {
    serviceName: string;
    client: HatchetClient;
    name: string;
    killing: boolean;
    handle_kill: boolean;
    action_registry: ActionRegistry;
    listener: ActionListener | undefined;
    futures: Record<Action['stepRunId'], HatchetPromise<any>>;
    contexts: Record<Action['stepRunId'], Context<any, any>>;
    logger: Logger;
    constructor(client: HatchetClient, options: {
        name: string;
        handleKill?: boolean;
    });
    registerWorkflow(workflow: Workflow): Promise<void>;
    registerAction<T, K>(actionId: string, action: StepRunFunction<T, K>): void;
    handleStartStepRun(action: Action): void;
    handleStartGroupKeyRun(action: Action): void;
    getStepActionEvent(action: Action, eventType: StepActionEventType, payload?: any): StepActionEvent;
    getGroupKeyActionEvent(action: Action, eventType: GroupKeyActionEventType, payload?: any): GroupKeyActionEvent;
    handleCancelStepRun(action: Action): void;
    stop(): Promise<void>;
    exitGracefully(): Promise<void>;
    start(): Promise<void>;
}
