import type { CallContext, CallOptions } from "nice-grpc-common";
import * as _m0 from "protobufjs/minimal";
export declare const protobufPackage = "";
export declare enum ConcurrencyLimitStrategy {
    CANCEL_IN_PROGRESS = 0,
    DROP_NEWEST = 1,
    QUEUE_NEWEST = 2,
    UNRECOGNIZED = -1
}
export declare function concurrencyLimitStrategyFromJSON(object: any): ConcurrencyLimitStrategy;
export declare function concurrencyLimitStrategyToJSON(object: ConcurrencyLimitStrategy): string;
export interface PutWorkflowRequest {
    opts: CreateWorkflowVersionOpts | undefined;
}
/** CreateWorkflowVersionOpts represents options to create a workflow version. */
export interface CreateWorkflowVersionOpts {
    /** (required) the workflow name */
    name: string;
    /** (optional) the workflow description */
    description: string;
    /** (required) the workflow version */
    version: string;
    /** (optional) event triggers for the workflow */
    eventTriggers: string[];
    /** (optional) cron triggers for the workflow */
    cronTriggers: string[];
    /** (optional) scheduled triggers for the workflow */
    scheduledTriggers: Date[];
    /** (required) the workflow jobs */
    jobs: CreateWorkflowJobOpts[];
    /** (optional) the workflow concurrency options */
    concurrency: WorkflowConcurrencyOpts | undefined;
}
export interface WorkflowConcurrencyOpts {
    /** (required) the action id for getting the concurrency group */
    action: string;
    /** (optional) the maximum number of concurrent workflow runs, default 1 */
    maxRuns: number;
    /** (optional) the strategy to use when the concurrency limit is reached, default CANCEL_IN_PROGRESS */
    limitStrategy: ConcurrencyLimitStrategy;
}
/** CreateWorkflowJobOpts represents options to create a workflow job. */
export interface CreateWorkflowJobOpts {
    /** (required) the job name */
    name: string;
    /** (optional) the job description */
    description: string;
    /** (optional) the job timeout */
    timeout: string;
    /** (required) the job steps */
    steps: CreateWorkflowStepOpts[];
}
/** CreateWorkflowStepOpts represents options to create a workflow step. */
export interface CreateWorkflowStepOpts {
    /** (required) the step name */
    readableId: string;
    /** (required) the step action id */
    action: string;
    /** (optional) the step timeout */
    timeout: string;
    /** (optional) the step inputs, assuming string representation of JSON */
    inputs: string;
    /** (optional) the step parents. if none are passed in, this is a root step */
    parents: string[];
    /** (optional) the custom step user data, assuming string representation of JSON */
    userData: string;
    /** (optional) the number of retries for the step, default 0 */
    retries: number;
}
/** ListWorkflowsRequest is the request for ListWorkflows. */
export interface ListWorkflowsRequest {
}
export interface ScheduleWorkflowRequest {
    workflowId: string;
    schedules: Date[];
    /** (optional) the input data for the workflow */
    input: string;
}
/** ListWorkflowsResponse is the response for ListWorkflows. */
export interface ListWorkflowsResponse {
    workflows: Workflow[];
}
/** ListWorkflowsForEventRequest is the request for ListWorkflowsForEvent. */
export interface ListWorkflowsForEventRequest {
    eventKey: string;
}
/** Workflow represents the Workflow model. */
export interface Workflow {
    id: string;
    createdAt: Date | undefined;
    updatedAt: Date | undefined;
    tenantId: string;
    name: string;
    /** Optional */
    description: string | undefined;
    versions: WorkflowVersion[];
}
/** WorkflowVersion represents the WorkflowVersion model. */
export interface WorkflowVersion {
    id: string;
    createdAt: Date | undefined;
    updatedAt: Date | undefined;
    version: string;
    order: number;
    workflowId: string;
    triggers: WorkflowTriggers | undefined;
    jobs: Job[];
}
/** WorkflowTriggers represents the WorkflowTriggers model. */
export interface WorkflowTriggers {
    id: string;
    createdAt: Date | undefined;
    updatedAt: Date | undefined;
    workflowVersionId: string;
    tenantId: string;
    events: WorkflowTriggerEventRef[];
    crons: WorkflowTriggerCronRef[];
}
/** WorkflowTriggerEventRef represents the WorkflowTriggerEventRef model. */
export interface WorkflowTriggerEventRef {
    parentId: string;
    eventKey: string;
}
/** WorkflowTriggerCronRef represents the WorkflowTriggerCronRef model. */
export interface WorkflowTriggerCronRef {
    parentId: string;
    cron: string;
}
/** Job represents the Job model. */
export interface Job {
    id: string;
    createdAt: Date | undefined;
    updatedAt: Date | undefined;
    tenantId: string;
    workflowVersionId: string;
    name: string;
    /** Optional */
    description: string | undefined;
    steps: Step[];
    /** Optional */
    timeout: string | undefined;
}
/** Step represents the Step model. */
export interface Step {
    id: string;
    createdAt: Date | undefined;
    updatedAt: Date | undefined;
    /** Optional */
    readableId: string | undefined;
    tenantId: string;
    jobId: string;
    action: string;
    /** Optional */
    timeout: string | undefined;
    parents: string[];
    children: string[];
}
export interface DeleteWorkflowRequest {
    workflowId: string;
}
export interface GetWorkflowByNameRequest {
    name: string;
}
export interface TriggerWorkflowRequest {
    name: string;
    /** (optional) the input data for the workflow */
    input: string;
}
export interface TriggerWorkflowResponse {
    workflowRunId: string;
}
export declare const PutWorkflowRequest: {
    encode(message: PutWorkflowRequest, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): PutWorkflowRequest;
    fromJSON(object: any): PutWorkflowRequest;
    toJSON(message: PutWorkflowRequest): unknown;
    create(base?: DeepPartial<PutWorkflowRequest>): PutWorkflowRequest;
    fromPartial(object: DeepPartial<PutWorkflowRequest>): PutWorkflowRequest;
};
export declare const CreateWorkflowVersionOpts: {
    encode(message: CreateWorkflowVersionOpts, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): CreateWorkflowVersionOpts;
    fromJSON(object: any): CreateWorkflowVersionOpts;
    toJSON(message: CreateWorkflowVersionOpts): unknown;
    create(base?: DeepPartial<CreateWorkflowVersionOpts>): CreateWorkflowVersionOpts;
    fromPartial(object: DeepPartial<CreateWorkflowVersionOpts>): CreateWorkflowVersionOpts;
};
export declare const WorkflowConcurrencyOpts: {
    encode(message: WorkflowConcurrencyOpts, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): WorkflowConcurrencyOpts;
    fromJSON(object: any): WorkflowConcurrencyOpts;
    toJSON(message: WorkflowConcurrencyOpts): unknown;
    create(base?: DeepPartial<WorkflowConcurrencyOpts>): WorkflowConcurrencyOpts;
    fromPartial(object: DeepPartial<WorkflowConcurrencyOpts>): WorkflowConcurrencyOpts;
};
export declare const CreateWorkflowJobOpts: {
    encode(message: CreateWorkflowJobOpts, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): CreateWorkflowJobOpts;
    fromJSON(object: any): CreateWorkflowJobOpts;
    toJSON(message: CreateWorkflowJobOpts): unknown;
    create(base?: DeepPartial<CreateWorkflowJobOpts>): CreateWorkflowJobOpts;
    fromPartial(object: DeepPartial<CreateWorkflowJobOpts>): CreateWorkflowJobOpts;
};
export declare const CreateWorkflowStepOpts: {
    encode(message: CreateWorkflowStepOpts, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): CreateWorkflowStepOpts;
    fromJSON(object: any): CreateWorkflowStepOpts;
    toJSON(message: CreateWorkflowStepOpts): unknown;
    create(base?: DeepPartial<CreateWorkflowStepOpts>): CreateWorkflowStepOpts;
    fromPartial(object: DeepPartial<CreateWorkflowStepOpts>): CreateWorkflowStepOpts;
};
export declare const ListWorkflowsRequest: {
    encode(_: ListWorkflowsRequest, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): ListWorkflowsRequest;
    fromJSON(_: any): ListWorkflowsRequest;
    toJSON(_: ListWorkflowsRequest): unknown;
    create(base?: DeepPartial<ListWorkflowsRequest>): ListWorkflowsRequest;
    fromPartial(_: DeepPartial<ListWorkflowsRequest>): ListWorkflowsRequest;
};
export declare const ScheduleWorkflowRequest: {
    encode(message: ScheduleWorkflowRequest, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): ScheduleWorkflowRequest;
    fromJSON(object: any): ScheduleWorkflowRequest;
    toJSON(message: ScheduleWorkflowRequest): unknown;
    create(base?: DeepPartial<ScheduleWorkflowRequest>): ScheduleWorkflowRequest;
    fromPartial(object: DeepPartial<ScheduleWorkflowRequest>): ScheduleWorkflowRequest;
};
export declare const ListWorkflowsResponse: {
    encode(message: ListWorkflowsResponse, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): ListWorkflowsResponse;
    fromJSON(object: any): ListWorkflowsResponse;
    toJSON(message: ListWorkflowsResponse): unknown;
    create(base?: DeepPartial<ListWorkflowsResponse>): ListWorkflowsResponse;
    fromPartial(object: DeepPartial<ListWorkflowsResponse>): ListWorkflowsResponse;
};
export declare const ListWorkflowsForEventRequest: {
    encode(message: ListWorkflowsForEventRequest, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): ListWorkflowsForEventRequest;
    fromJSON(object: any): ListWorkflowsForEventRequest;
    toJSON(message: ListWorkflowsForEventRequest): unknown;
    create(base?: DeepPartial<ListWorkflowsForEventRequest>): ListWorkflowsForEventRequest;
    fromPartial(object: DeepPartial<ListWorkflowsForEventRequest>): ListWorkflowsForEventRequest;
};
export declare const Workflow: {
    encode(message: Workflow, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): Workflow;
    fromJSON(object: any): Workflow;
    toJSON(message: Workflow): unknown;
    create(base?: DeepPartial<Workflow>): Workflow;
    fromPartial(object: DeepPartial<Workflow>): Workflow;
};
export declare const WorkflowVersion: {
    encode(message: WorkflowVersion, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): WorkflowVersion;
    fromJSON(object: any): WorkflowVersion;
    toJSON(message: WorkflowVersion): unknown;
    create(base?: DeepPartial<WorkflowVersion>): WorkflowVersion;
    fromPartial(object: DeepPartial<WorkflowVersion>): WorkflowVersion;
};
export declare const WorkflowTriggers: {
    encode(message: WorkflowTriggers, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): WorkflowTriggers;
    fromJSON(object: any): WorkflowTriggers;
    toJSON(message: WorkflowTriggers): unknown;
    create(base?: DeepPartial<WorkflowTriggers>): WorkflowTriggers;
    fromPartial(object: DeepPartial<WorkflowTriggers>): WorkflowTriggers;
};
export declare const WorkflowTriggerEventRef: {
    encode(message: WorkflowTriggerEventRef, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): WorkflowTriggerEventRef;
    fromJSON(object: any): WorkflowTriggerEventRef;
    toJSON(message: WorkflowTriggerEventRef): unknown;
    create(base?: DeepPartial<WorkflowTriggerEventRef>): WorkflowTriggerEventRef;
    fromPartial(object: DeepPartial<WorkflowTriggerEventRef>): WorkflowTriggerEventRef;
};
export declare const WorkflowTriggerCronRef: {
    encode(message: WorkflowTriggerCronRef, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): WorkflowTriggerCronRef;
    fromJSON(object: any): WorkflowTriggerCronRef;
    toJSON(message: WorkflowTriggerCronRef): unknown;
    create(base?: DeepPartial<WorkflowTriggerCronRef>): WorkflowTriggerCronRef;
    fromPartial(object: DeepPartial<WorkflowTriggerCronRef>): WorkflowTriggerCronRef;
};
export declare const Job: {
    encode(message: Job, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): Job;
    fromJSON(object: any): Job;
    toJSON(message: Job): unknown;
    create(base?: DeepPartial<Job>): Job;
    fromPartial(object: DeepPartial<Job>): Job;
};
export declare const Step: {
    encode(message: Step, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): Step;
    fromJSON(object: any): Step;
    toJSON(message: Step): unknown;
    create(base?: DeepPartial<Step>): Step;
    fromPartial(object: DeepPartial<Step>): Step;
};
export declare const DeleteWorkflowRequest: {
    encode(message: DeleteWorkflowRequest, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): DeleteWorkflowRequest;
    fromJSON(object: any): DeleteWorkflowRequest;
    toJSON(message: DeleteWorkflowRequest): unknown;
    create(base?: DeepPartial<DeleteWorkflowRequest>): DeleteWorkflowRequest;
    fromPartial(object: DeepPartial<DeleteWorkflowRequest>): DeleteWorkflowRequest;
};
export declare const GetWorkflowByNameRequest: {
    encode(message: GetWorkflowByNameRequest, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): GetWorkflowByNameRequest;
    fromJSON(object: any): GetWorkflowByNameRequest;
    toJSON(message: GetWorkflowByNameRequest): unknown;
    create(base?: DeepPartial<GetWorkflowByNameRequest>): GetWorkflowByNameRequest;
    fromPartial(object: DeepPartial<GetWorkflowByNameRequest>): GetWorkflowByNameRequest;
};
export declare const TriggerWorkflowRequest: {
    encode(message: TriggerWorkflowRequest, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): TriggerWorkflowRequest;
    fromJSON(object: any): TriggerWorkflowRequest;
    toJSON(message: TriggerWorkflowRequest): unknown;
    create(base?: DeepPartial<TriggerWorkflowRequest>): TriggerWorkflowRequest;
    fromPartial(object: DeepPartial<TriggerWorkflowRequest>): TriggerWorkflowRequest;
};
export declare const TriggerWorkflowResponse: {
    encode(message: TriggerWorkflowResponse, writer?: _m0.Writer): _m0.Writer;
    decode(input: _m0.Reader | Uint8Array, length?: number): TriggerWorkflowResponse;
    fromJSON(object: any): TriggerWorkflowResponse;
    toJSON(message: TriggerWorkflowResponse): unknown;
    create(base?: DeepPartial<TriggerWorkflowResponse>): TriggerWorkflowResponse;
    fromPartial(object: DeepPartial<TriggerWorkflowResponse>): TriggerWorkflowResponse;
};
/** WorkflowService represents a set of RPCs for managing workflows. */
export type WorkflowServiceDefinition = typeof WorkflowServiceDefinition;
export declare const WorkflowServiceDefinition: {
    readonly name: "WorkflowService";
    readonly fullName: "WorkflowService";
    readonly methods: {
        readonly listWorkflows: {
            readonly name: "ListWorkflows";
            readonly requestType: {
                encode(_: ListWorkflowsRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): ListWorkflowsRequest;
                fromJSON(_: any): ListWorkflowsRequest;
                toJSON(_: ListWorkflowsRequest): unknown;
                create(base?: DeepPartial<ListWorkflowsRequest>): ListWorkflowsRequest;
                fromPartial(_: DeepPartial<ListWorkflowsRequest>): ListWorkflowsRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                encode(message: ListWorkflowsResponse, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): ListWorkflowsResponse;
                fromJSON(object: any): ListWorkflowsResponse;
                toJSON(message: ListWorkflowsResponse): unknown;
                create(base?: DeepPartial<ListWorkflowsResponse>): ListWorkflowsResponse;
                fromPartial(object: DeepPartial<ListWorkflowsResponse>): ListWorkflowsResponse;
            };
            readonly responseStream: false;
            readonly options: {};
        };
        readonly putWorkflow: {
            readonly name: "PutWorkflow";
            readonly requestType: {
                encode(message: PutWorkflowRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): PutWorkflowRequest;
                fromJSON(object: any): PutWorkflowRequest;
                toJSON(message: PutWorkflowRequest): unknown;
                create(base?: DeepPartial<PutWorkflowRequest>): PutWorkflowRequest;
                fromPartial(object: DeepPartial<PutWorkflowRequest>): PutWorkflowRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                encode(message: WorkflowVersion, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): WorkflowVersion;
                fromJSON(object: any): WorkflowVersion;
                toJSON(message: WorkflowVersion): unknown;
                create(base?: DeepPartial<WorkflowVersion>): WorkflowVersion;
                fromPartial(object: DeepPartial<WorkflowVersion>): WorkflowVersion;
            };
            readonly responseStream: false;
            readonly options: {};
        };
        readonly scheduleWorkflow: {
            readonly name: "ScheduleWorkflow";
            readonly requestType: {
                encode(message: ScheduleWorkflowRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): ScheduleWorkflowRequest;
                fromJSON(object: any): ScheduleWorkflowRequest;
                toJSON(message: ScheduleWorkflowRequest): unknown;
                create(base?: DeepPartial<ScheduleWorkflowRequest>): ScheduleWorkflowRequest;
                fromPartial(object: DeepPartial<ScheduleWorkflowRequest>): ScheduleWorkflowRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                encode(message: WorkflowVersion, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): WorkflowVersion;
                fromJSON(object: any): WorkflowVersion;
                toJSON(message: WorkflowVersion): unknown;
                create(base?: DeepPartial<WorkflowVersion>): WorkflowVersion;
                fromPartial(object: DeepPartial<WorkflowVersion>): WorkflowVersion;
            };
            readonly responseStream: false;
            readonly options: {};
        };
        readonly triggerWorkflow: {
            readonly name: "TriggerWorkflow";
            readonly requestType: {
                encode(message: TriggerWorkflowRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): TriggerWorkflowRequest;
                fromJSON(object: any): TriggerWorkflowRequest;
                toJSON(message: TriggerWorkflowRequest): unknown;
                create(base?: DeepPartial<TriggerWorkflowRequest>): TriggerWorkflowRequest;
                fromPartial(object: DeepPartial<TriggerWorkflowRequest>): TriggerWorkflowRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                encode(message: TriggerWorkflowResponse, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): TriggerWorkflowResponse;
                fromJSON(object: any): TriggerWorkflowResponse;
                toJSON(message: TriggerWorkflowResponse): unknown;
                create(base?: DeepPartial<TriggerWorkflowResponse>): TriggerWorkflowResponse;
                fromPartial(object: DeepPartial<TriggerWorkflowResponse>): TriggerWorkflowResponse;
            };
            readonly responseStream: false;
            readonly options: {};
        };
        readonly getWorkflowByName: {
            readonly name: "GetWorkflowByName";
            readonly requestType: {
                encode(message: GetWorkflowByNameRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): GetWorkflowByNameRequest;
                fromJSON(object: any): GetWorkflowByNameRequest;
                toJSON(message: GetWorkflowByNameRequest): unknown;
                create(base?: DeepPartial<GetWorkflowByNameRequest>): GetWorkflowByNameRequest;
                fromPartial(object: DeepPartial<GetWorkflowByNameRequest>): GetWorkflowByNameRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                encode(message: Workflow, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): Workflow;
                fromJSON(object: any): Workflow;
                toJSON(message: Workflow): unknown;
                create(base?: DeepPartial<Workflow>): Workflow;
                fromPartial(object: DeepPartial<Workflow>): Workflow;
            };
            readonly responseStream: false;
            readonly options: {};
        };
        readonly listWorkflowsForEvent: {
            readonly name: "ListWorkflowsForEvent";
            readonly requestType: {
                encode(message: ListWorkflowsForEventRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): ListWorkflowsForEventRequest;
                fromJSON(object: any): ListWorkflowsForEventRequest;
                toJSON(message: ListWorkflowsForEventRequest): unknown;
                create(base?: DeepPartial<ListWorkflowsForEventRequest>): ListWorkflowsForEventRequest;
                fromPartial(object: DeepPartial<ListWorkflowsForEventRequest>): ListWorkflowsForEventRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                encode(message: ListWorkflowsResponse, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): ListWorkflowsResponse;
                fromJSON(object: any): ListWorkflowsResponse;
                toJSON(message: ListWorkflowsResponse): unknown;
                create(base?: DeepPartial<ListWorkflowsResponse>): ListWorkflowsResponse;
                fromPartial(object: DeepPartial<ListWorkflowsResponse>): ListWorkflowsResponse;
            };
            readonly responseStream: false;
            readonly options: {};
        };
        readonly deleteWorkflow: {
            readonly name: "DeleteWorkflow";
            readonly requestType: {
                encode(message: DeleteWorkflowRequest, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): DeleteWorkflowRequest;
                fromJSON(object: any): DeleteWorkflowRequest;
                toJSON(message: DeleteWorkflowRequest): unknown;
                create(base?: DeepPartial<DeleteWorkflowRequest>): DeleteWorkflowRequest;
                fromPartial(object: DeepPartial<DeleteWorkflowRequest>): DeleteWorkflowRequest;
            };
            readonly requestStream: false;
            readonly responseType: {
                encode(message: Workflow, writer?: _m0.Writer): _m0.Writer;
                decode(input: _m0.Reader | Uint8Array, length?: number): Workflow;
                fromJSON(object: any): Workflow;
                toJSON(message: Workflow): unknown;
                create(base?: DeepPartial<Workflow>): Workflow;
                fromPartial(object: DeepPartial<Workflow>): Workflow;
            };
            readonly responseStream: false;
            readonly options: {};
        };
    };
};
export interface WorkflowServiceImplementation<CallContextExt = {}> {
    listWorkflows(request: ListWorkflowsRequest, context: CallContext & CallContextExt): Promise<DeepPartial<ListWorkflowsResponse>>;
    putWorkflow(request: PutWorkflowRequest, context: CallContext & CallContextExt): Promise<DeepPartial<WorkflowVersion>>;
    scheduleWorkflow(request: ScheduleWorkflowRequest, context: CallContext & CallContextExt): Promise<DeepPartial<WorkflowVersion>>;
    triggerWorkflow(request: TriggerWorkflowRequest, context: CallContext & CallContextExt): Promise<DeepPartial<TriggerWorkflowResponse>>;
    getWorkflowByName(request: GetWorkflowByNameRequest, context: CallContext & CallContextExt): Promise<DeepPartial<Workflow>>;
    listWorkflowsForEvent(request: ListWorkflowsForEventRequest, context: CallContext & CallContextExt): Promise<DeepPartial<ListWorkflowsResponse>>;
    deleteWorkflow(request: DeleteWorkflowRequest, context: CallContext & CallContextExt): Promise<DeepPartial<Workflow>>;
}
export interface WorkflowServiceClient<CallOptionsExt = {}> {
    listWorkflows(request: DeepPartial<ListWorkflowsRequest>, options?: CallOptions & CallOptionsExt): Promise<ListWorkflowsResponse>;
    putWorkflow(request: DeepPartial<PutWorkflowRequest>, options?: CallOptions & CallOptionsExt): Promise<WorkflowVersion>;
    scheduleWorkflow(request: DeepPartial<ScheduleWorkflowRequest>, options?: CallOptions & CallOptionsExt): Promise<WorkflowVersion>;
    triggerWorkflow(request: DeepPartial<TriggerWorkflowRequest>, options?: CallOptions & CallOptionsExt): Promise<TriggerWorkflowResponse>;
    getWorkflowByName(request: DeepPartial<GetWorkflowByNameRequest>, options?: CallOptions & CallOptionsExt): Promise<Workflow>;
    listWorkflowsForEvent(request: DeepPartial<ListWorkflowsForEventRequest>, options?: CallOptions & CallOptionsExt): Promise<ListWorkflowsResponse>;
    deleteWorkflow(request: DeepPartial<DeleteWorkflowRequest>, options?: CallOptions & CallOptionsExt): Promise<Workflow>;
}
type Builtin = Date | Function | Uint8Array | string | number | boolean | undefined;
export type DeepPartial<T> = T extends Builtin ? T : T extends globalThis.Array<infer U> ? globalThis.Array<DeepPartial<U>> : T extends ReadonlyArray<infer U> ? ReadonlyArray<DeepPartial<U>> : T extends {} ? {
    [K in keyof T]?: DeepPartial<T[K]>;
} : Partial<T>;
export {};
