"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ConfigLoader = void 0;
const yaml_1 = require("yaml");
const fs_1 = require("fs");
const p = __importStar(require("path"));
const zod_1 = require("zod");
const hatchet_client_1 = require("../../clients/hatchet-client");
const nice_grpc_1 = require("nice-grpc");
const token_1 = require("./token");
const DEFAULT_CONFIG_FILE = '.hatchet.yaml';
class ConfigLoader {
    static loadClientConfig(config) {
        var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m, _o, _p, _q, _r, _s, _t, _u, _v, _w;
        const yaml = this.loadYamlConfig(config === null || config === void 0 ? void 0 : config.path);
        const tlsConfig = {
            tls_strategy: (_c = (_b = (_a = yaml === null || yaml === void 0 ? void 0 : yaml.tls_config) === null || _a === void 0 ? void 0 : _a.tls_strategy) !== null && _b !== void 0 ? _b : this.env('HATCHET_CLIENT_TLS_STRATEGY')) !== null && _c !== void 0 ? _c : 'tls',
            cert_file: (_e = (_d = yaml === null || yaml === void 0 ? void 0 : yaml.tls_config) === null || _d === void 0 ? void 0 : _d.cert_file) !== null && _e !== void 0 ? _e : this.env('HATCHET_CLIENT_TLS_CERT_FILE'),
            key_file: (_g = (_f = yaml === null || yaml === void 0 ? void 0 : yaml.tls_config) === null || _f === void 0 ? void 0 : _f.key_file) !== null && _g !== void 0 ? _g : this.env('HATCHET_CLIENT_TLS_KEY_FILE'),
            ca_file: (_j = (_h = yaml === null || yaml === void 0 ? void 0 : yaml.tls_config) === null || _h === void 0 ? void 0 : _h.ca_file) !== null && _j !== void 0 ? _j : this.env('HATCHET_CLIENT_TLS_ROOT_CA_FILE'),
            server_name: (_l = (_k = yaml === null || yaml === void 0 ? void 0 : yaml.tls_config) === null || _k === void 0 ? void 0 : _k.server_name) !== null && _l !== void 0 ? _l : this.env('HATCHET_CLIENT_TLS_SERVER_NAME'),
        };
        const token = (_m = yaml === null || yaml === void 0 ? void 0 : yaml.token) !== null && _m !== void 0 ? _m : this.env('HATCHET_CLIENT_TOKEN');
        let grpcBroadcastAddress;
        let apiUrl;
        const tenantId = (0, token_1.getTenantIdFromJWT)(token);
        if (!tenantId) {
            throw new Error('Tenant ID not found in subject claim of token');
        }
        try {
            const addresses = (0, token_1.getAddressesFromJWT)(token);
            grpcBroadcastAddress =
                (_p = (_o = yaml === null || yaml === void 0 ? void 0 : yaml.host_port) !== null && _o !== void 0 ? _o : this.env('HATCHET_CLIENT_HOST_PORT')) !== null && _p !== void 0 ? _p : addresses.grpcBroadcastAddress;
            apiUrl = (_r = (_q = yaml === null || yaml === void 0 ? void 0 : yaml.api_url) !== null && _q !== void 0 ? _q : this.env('HATCHET_CLIENT_API_URL')) !== null && _r !== void 0 ? _r : addresses.serverUrl;
        }
        catch (e) {
            grpcBroadcastAddress = (_s = yaml === null || yaml === void 0 ? void 0 : yaml.host_port) !== null && _s !== void 0 ? _s : this.env('HATCHET_CLIENT_HOST_PORT');
            apiUrl = (_t = yaml === null || yaml === void 0 ? void 0 : yaml.api_url) !== null && _t !== void 0 ? _t : this.env('HATCHET_CLIENT_API_URL');
        }
        return {
            token: (_u = yaml === null || yaml === void 0 ? void 0 : yaml.token) !== null && _u !== void 0 ? _u : this.env('HATCHET_CLIENT_TOKEN'),
            host_port: grpcBroadcastAddress,
            api_url: apiUrl,
            tls_config: tlsConfig,
            log_level: (_w = (_v = yaml === null || yaml === void 0 ? void 0 : yaml.log_level) !== null && _v !== void 0 ? _v : this.env('HATCHET_CLIENT_LOG_LEVEL')) !== null && _w !== void 0 ? _w : 'INFO',
            tenant_id: tenantId,
        };
    }
    static get default_yaml_config_path() {
        return p.join(process.cwd(), DEFAULT_CONFIG_FILE);
    }
    static createCredentials(config) {
        if (config.tls_strategy === 'tls') {
            const rootCerts = config.ca_file ? (0, fs_1.readFileSync)(config.ca_file) : undefined;
            return nice_grpc_1.ChannelCredentials.createSsl(rootCerts);
        }
        const rootCerts = config.ca_file ? (0, fs_1.readFileSync)(config.ca_file) : null;
        const privateKey = config.key_file ? (0, fs_1.readFileSync)(config.key_file) : null;
        const certChain = config.cert_file ? (0, fs_1.readFileSync)(config.cert_file) : null;
        return nice_grpc_1.ChannelCredentials.createSsl(rootCerts, privateKey, certChain);
    }
    static loadYamlConfig(path) {
        try {
            const configFile = (0, fs_1.readFileSync)(p.join(__dirname, path !== null && path !== void 0 ? path : this.default_yaml_config_path), 'utf8');
            const config = (0, yaml_1.parse)(configFile);
            hatchet_client_1.ClientConfigSchema.partial().parse(config);
            return config;
        }
        catch (e) {
            if (!path)
                return undefined;
            if (e instanceof zod_1.z.ZodError) {
                throw new Error(`Invalid yaml config: ${e.message}`);
            }
            throw e;
        }
    }
    static env(name) {
        return process.env[name];
    }
}
exports.ConfigLoader = ConfigLoader;
